<template>
  <div>
    <div class="shopdesc">{{ shop.description }}</div>
    <div id="main">
      <table border="0" width="" id="recentPatientsTable">
        <thead>
          <tr>
            <th>Recent Patients</th>
            <th>Diagnosis</th>
            <th>Time</th>
          </tr>
        </thead>
        <tbody v-show="recentPatients[0]">
          <tr
            v-for="patient in recentPatients"
            :key="patient.id">
            <td>{{ patient.patient_name }}</td>
            <td>
              <a
                @click.prevent="buildDiseaseModal(patient.diagnosed_with, $refs)"
                class="diseaselink">{{ patient.diagnosis }}
              </a>
            </td>
            <td>{{ moment.utc(patient.created_at).local().format("h:mm A") }}</td>
          </tr>
        </tbody>
      </table>
      <p v-show="!recentPatients[0]">No Recent Diagnoses.</p>
    </div>
    <shop-modal
    ref="diseaseModal">
      <div slot="disease" id="overlay">
        <div
          id="diseasewindow"
          class="modalwindow disease popup">
          <div id="diseaseTemplate">
            <h1>{{selectedDisease.medical_name}}</h1>
            <div class="details">
              <h2>What is it?</h2>
                <p>{{ selectedDisease.description }}</p>
              <h2>Affected Parts of Body</h2>
                <p> {{ selectedDisease.affected_body_parts }}</p>
              <h2>Signs and Symptoms</h2>
              <ul>
                <li
                  :key="index"
                  v-for="(symptom, index) in relatedSymptoms">{{ symptom.title }}
                </li>
              </ul>
              <h2>Causes</h2>
              <ul>
                <li
                  :key="index"
                  v-for="(cause, index) in selectedDisease.causes">{{ cause }}
                </li>
              </ul>
              <h2>How to Prevent</h2>
              <ul>
                <li
                  :key="index"
                  v-for="(measure, index) in selectedDisease.preventative_measures">{{ measure }}
                </li>
              </ul>
              <h2>Treatment</h2>
              <ul>
                <li
                  :key="index"
                  v-for="(treatment, index) in selectedDisease.treatment_options">{{ treatment }}
                </li>
              </ul>
              <p>&nbsp;</p>
            </div>
            <div class="gradient"></div>
            <a
              @click="$refs.diseaseModal.Close()"
              class="button close">Close Window</a>
          </div>
        </div>
      </div>
    </shop-modal>
  </div>
</template>

<script>
import ShopModal from '../../../../shared/views/ShopModal.vue';

export default {
  components: {
    ShopModal
  },
  props: {
    shop: Object,
    recentPatients: Array
  },
  methods: {
    buildDiseaseModal(disease, ref) {
      ref.diseaseModal.Open();
      this.selectedDisease = disease;
      this.findSymptoms(disease);
    },
    findSymptoms(disease) {
      const data = { disease_id: disease.disease_id };
      this.relatedSymptoms = [];
      app.session.SetSession()
        .then( () => {
          app.api.Post("/medical/findsymptoms/" + app.session.data.id, data)
            .then( Response => {
              console.log(Response);
              this.relatedSymptoms = Response;
            })
            .catch( x => app.Message( x.error, "error" ));
      });
    },
  },
  data() {
    return {
      selectedDisease: {},
      relatedSymptoms: [],
    }
  }
}
</script>

<style>

</style>
